* quayside-newcastle.jpg
  * "043262:Quayside above The Close Newcastle upon Tyne City Engineers 1972" by Newcastle Libraries
  * https://wordpress.org/openverse/image/a65eed1d-28f7-4d16-8733-4191e19188c7
  * License: Public Domain

* anchovy-nypl.jpg
  * "Anchovy (Clupea encrasicolus) illustration from The Natural History of British Fishes (1802)
    by Edward Donovan (1768-1837). Original from The New York Public Library. Digitally enhanced by
    rawpixel." by New York Public Library
  * https://wordpress.org/openverse/image/07e70fd6-c69a-4090-b2cc-a502207d6c69
  * License: Public Domain

* home-sweet-home-cdk.jpg
  "Home Sweet Home" by Crusty Da Klown
  https://wordpress.org/openverse/image/0379753f-19c3-44a3-8a2a-fb1b7685de55
  * License: Public Domain

* nice-wheels-cdk.jpg
  "Nice wheels" by Crusty Da Klown
  https://www.flickr.com/photos/148598741@N02/52238255462/
  * License: Public Domain

* stormy-cdk.jpg
  "Stormy" by Crusty Da Klown
  https://wordpress.org/openverse/image/bc3bc07e-6797-4aae-a0ec-4f5f60208c93
  * License: Public Domain
